//
//  AppModel.swift
//  Restaurants
//
//  Created by Radu Ionescu on 22/03/2017.
//  Copyright © 2017 lab. All rights reserved.
//

import Foundation

class AppModel
{
    static var sharedModel: AppModel {
        
        struct Holder
        {
            static var model: AppModel?
        }
        
        if Holder.model == nil
        {
            Holder.model = AppModel()
            Holder.model?.images=[:]
        }
        
        return Holder.model!
    }
    
    var restaurants: [Any]?
    var images: [String: Data]?
    
    func downloadRestaurants()
    {
        let url = URL(string:"http://raduionescu.herokuapp.com/swift/restaurants.json")
        let session = URLSession.shared
        
        var request = URLRequest(url:url!,
                                 cachePolicy:.reloadIgnoringLocalCacheData,
                                 timeoutInterval:90.0)
        
        request.httpMethod = "GET"
        
        let task = session.dataTask(with: request) { [unowned self] (data, response, error) in
            
            if error != nil
            {
                print("\(String(describing: error))")
            }
            else if let response = response, let data = data
            {
                let httpResponse = response as! HTTPURLResponse
                
                if httpResponse.statusCode == 200
                {
                    do
                    {
                        let json = try JSONSerialization.jsonObject(with: data,
                                                                    options: [.allowFragments, .mutableContainers])
                        let dict = json as! [String:Any]
                        let restaurants = dict["restaurants"] as! [Any]
                        self.restaurants = restaurants
                        
                        DispatchQueue.main.async {
                            
                            NotificationCenter.default.post(name: NSNotification.Name(rawValue: "didReceiveRestaurantsData"),
                                                            object: self)
                        }
                    }
                    catch
                    {
                        
                    }
                }
            }
        }
        
        task.resume()
    }
}

